[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-devel] [PATCH] use INT64_MAX as max expiration



Currently, the max expiration time is 2147483647ns(INT32_MAX ns). This is 
enough when guest is busy, but when guest is idle, the next timer will be later 
than INT32_MAX ns. And those meaningless alarm will harm the pkg C-state.

Signed-off-by: Yang Zhang <yang.z.zhang@xxxxxxxxx>
---
 vl.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/vl.c b/vl.c
index be8587a..40486eb 100644
--- a/vl.c
+++ b/vl.c
@@ -1410,8 +1410,8 @@ static int64_t qemu_next_deadline(void)
         delta = active_timers[QEMU_TIMER_VIRTUAL]->expire_time -
                      qemu_get_clock(vm_clock);
     } else {
-        /* To avoid problems with overflow limit this to 2^32.  */
-        delta = INT32_MAX;
+        /* To avoid problems with overflow limit this to 2^64 - 1000.  */
+        delta = INT64_MAX - 1000;
     }

     if (delta < 0)
@@ -1427,7 +1427,7 @@ static uint64_t qemu_next_deadline_dyntick(void)
     int64_t rtdelta;

     if (use_icount)
-        delta = INT32_MAX;
+        delta = INT64_MAX;
     else
         delta = (qemu_next_deadline() + 999) / 1000;

--
1.7.1

_______________________________________________
Xen-devel mailing list
Xen-devel@xxxxxxxxxxxxx
http://lists.xen.org/xen-devel


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.